/* SPDX-License-Identifier: MIT */


#include "../main_clear.hpp"


#define THIS_BACKEND "TPM1.X"


int main(int argc, char ** argv) {
	return do_clear_main(argc, argv, THIS_BACKEND, [](auto, auto) { return 0; }, [] { return 0; });
}
